@@ -1,7 +1,7 @@
 import { Sequelize, Op } from 'sequelize';
 import { FHIR_SEARCH_PARAMETERS } from '@tamanu/constants';
 import { jsonFromBase64, jsonToBase64 } from '@tamanu/utils/encodings';
-import { InvalidParameterError } from '@tamanu/shared/errors';
+import { InvalidParameterError } from '@tamanu/errors';
 import { toDateString } from '@tamanu/utils/dateTime';
 import {
   endOfDay,
