@@ -20,11 +20,14 @@ export const NON_SYNCING_TABLES = [
   'public.sync_sessions',
   'public.user_localisation_caches',
   'public.user_recently_viewed_patients',
+  'public.portal_one_time_tokens',
 ];
 
 export const NON_LOGGED_TABLES = [
   // logs
-  'logs.*',
+  'logs.changes',
+  'logs.accesses',
+  'logs.debug_logs',
 
   // internal authentication tables
   'public.one_time_logins',
